AirAsia plane reported missing with 162 passengers on board: latest - Telegraph
Description: Search teams in the Java Sea are to resume looking for bodies from AirAsia flight QZ8501 at dawn, as authorities say they could begin to wash ashore
Keywords: airasia, live, missing, malaysia, indonesia, singaport, Briton, missing plane, airasia, latest, news, plane, video,, Indonesia,Asia,World News,News

Accessibility links

- Skip to article
- Skip to navigation

Advertisement
Telegraph.co.uk
Search - enhanced by OpenText

Saturday 03 January 2015

- Home
- Video
- News
- World
- Sport
- Finance
- Comment
- Culture
- Travel
- Life
- Women
- Fashion
- Luxury
- Tech
- Cars

- USA
- Asia
- China
- Europe
- Middle East
- Australasia
- Africa
- South America
- Central Asia
- Expat
- Honduras

- Afghanistan
- Pakistan
- India
- North Korea
- South Korea
- Japan
- Kazakhstan

1. Home»
2. News»
3. World News»
4. Asia»
5. Indonesia

# AirAsia plane found in Java Sea: latest

## Search teams in the Java Sea are to resume looking for bodies from AirAsia flight QZ8501 at dawn, as authorities say they could begin to wash ashore

By Harriet Alexander, Andrew Marszal and Josie Ensor

5:00PM GMT 31 Dec 2014

Comments

90000
2014-12-31 17:13:38.0
http://www.telegraph.co.uk/news/worldnews/asia/indonesia/11315001/AirAsia-plane-reported-missing-with-162-passengers-onboard-latest.html?service=artBody
This page will automatically update every 90 secondsOn Off

• Seven bodies from 162 on board found so far
• AirAsia pilot's son 'thinks daddy is still at work'
• AirAsia plane found in Java Sea, in pictures
• Plane thought to be upside down in sea
• Brother of missing Briton speaks of 'unbearable' heartache
• Pilot had asked to change route to 'avoid bad weather'
• Air Asia missing plane: How the news unfolded

### Latest

17.00 We are going to leave our live coverage here for today, but will be back at first light in Indonesia (around midnight GMT) with further updates as the search continues.

Meanwhile, Jonathan Pearlman in Pangkalan Bun, and Tom Phillips in Surabaya have this wrap of the day's events:

AirAsia Flight QZ8501: evidence suggests plane stalled before passengers felt violent descent

16.06 AirAsia QZ8501 made an "unbelievably" steep climb before it crashed, possibly pushing it beyond the Airbus A320's limits, according to radar data, a source close to the investigation has told Reuters.

"So far, the numbers taken by the radar are unbelievably high. This rate of climb is very high, too high. It appears to be beyond the performance envelope of the aircraft," he said.

The source, who declined to be named, added that more information was needed to come to a firm conclusion.

15.25 As night falls in southeast Asia, the search has been called off until tomorrow.

Meanwhile, Indonesians in Surabaya, East Java are holding a candle-lit vigil for the victims of the crashed AirAsia airplane

14.53 These latest images from the search mission have just been released by the Malaysian Navy:

Royal Malaysian Navy ship KD Lekir is show here retrieving the body of a victim

The same ship is here shown retrieving AirAsia flight QZ8501's emergency evacuation tube

14.29 Indonesian authorities are hoping to bring the five remaining bodies that have been recovered from the AirAsia plane back to land at around midnight, local time. The bodies have been stranded on an Indonesian naval vessel and could not be flown back from sea due to the poor weather. Only two bodies were able to be transferred by helicopter.

The new plan is for the naval ship to approach land near the coastal town of Kumai and transfer the bodies to a smaller boat that can enter the town's bay. The bodies will be left in hospital overnight and then flown to Surabaya tomorrow. The plan was due to have happened already but was delayed due to the poor weather.

14.07 An Indonesian search and rescue official has cast further doubt on claims that one of the bodies recovered from the crashed AirAsia jet had been wearing a life jacket.

"There is no victim that has been found wearing a life jacket," said Tatang Zaenudin, deputy head of operations at the national search and rescue agency.

"We found a body at 8.20 a.m. and a life jacket at 10.32 a.m. so there was a time difference. This is the latest information we have," he added.

The same official told Reuters earlier that one of the recovered bodies had been wearing a life jacket

13.45 There remain several possible explanations for why QZ8501 crashed. David Millward, the Telegraph's US correspondent and former Transport Editor, explains the most likely:

The smart money seems to be moving towards the pitots freezing – they are the little detectors near the nose of the aircraft measuring wind velocity they are vital for the pilot when judging the wind speed. This is what did for the Air France airbus, albeit rather a larger one.

There was also a suggestion on NBC that the fuel flow could have been interfered with because of extreme cold. That is what caused the BA 747 to pancake at Heathrow a few years ago. Simplest way of explaining is to think of it as an aviation equivalent to a cardiac arrest because of blocked fuel intake pipes. It had a different engine, however to the BA jumbo.

13.08 Tony Fernandes, the Air Asia chief, has been speaking at Surabaya's airport about the rescue operation, badly hampered today by poor weather.

"The weather unfortunately is not looking good for the next two or three days," he told reporters. "That is slowing us down."

Mr Fernandes refused to discuss speculation about whether or not a passenger was found wearing a life-jacket but confirmed that the main fuselage of Flight QZ8501 had not been found.

12.15 More photos are coming in from the search.

11.48 There are still conflicting reports about whether a body was found wearing a life jacket.

We are trying to get the answers for you.

11.23 Our picture desk have compiled a gallery of some of the most powerful images from the search.

AirAsia plane found in Java Sea, in pictures

11.18 More from Tom Phillips in Indonesia.

I've just spoken to one of the relatives who has come to a Disaster Victim Identification centre set up beside the hospital.

"I hope they can identify my brother soon," said Sigit Heriyanto, who had three family members on the plane.

Family members are tonight giving blood samples for DNA analysis. But no more bodies are expected to arrive today.

10.58 The latest updates from Tom Phillips in Indonesia.

Police forensic chiefs have just been briefing us here at the hospital where 15 forensic doctors will identify victims brought here from crash site.

They don't expect any more bodies to arrive in Surabaya today because bad weather has hampered the search.

An AirAsia pilot, who is helping with the identification process, told me just after the bodies arrived:

It’s already 6 o’clock now. I guess it is very hard to find anything if it dark.

09.52 In Indonesia, Tom Phillips has been speaking to the family of the pilot, Captain Irianto.

He writes:

When the devastating images of Flight QZ8501's wreckage flashed up on television screens on Tuesday, few were left with any illusions about what had happened to the 162 people on board.

But on Wednesday, as the first of the victims' bodies were flown back to the Indonesian city of Surabaya, one person remained completely in the dark: an 8-year-old boy called Arya Galih Gegana.

Galih, as he is known, is the son of Irianto, the veteran pilot who was flying the doomed AirAsia flight when it took off in the early hours of Sunday. Relatives have yet to tell him that the father he so adored is gone.

"I told Galih that his father will not be coming straight home because he has another job to do," said Budi Sutiono, the pilot's 55-year-old brother and the boy's uncle. "He thinks daddy is still at work.

AirAsia pilot's son 'thinks daddy is still at work'

08.55 Here's the latest from our video team on the search for wreckage and bodies.

08.21 Following the offer by the British government to assist in the search for missing Air Asia flight QZ8501, an investigator from the UK's Air Accident Investigation Branch (AAIB) is now helping with the search for the plane's flight recorders.

The AAIB investigator has joined Singaporean experts to assist the Indonesian operation. They hope to reach the search area on an Indonesian naval vessel as soon as possible. The AAIB investigator is carrying specialist technical equipment that can help locate the flight recorders.

Moazzam Malik, the British Ambassador to Indonesia, said:

On behalf of British people and Her Majesty's Government I would like to express our deepest condolences to the family of the passengers and crew. Our thoughts and prayers are with them at this difficult time.

The UK Air Accident Investigation Branch has long experience, expertise and technical equipment that can help locate flight recorders underwater. I hope their assistance can help the Indonesian authorities locate the black box for Air Asia flight 8501 quickly. We stand ready to help with the subsequent investigation if required."

07.49 AirAsia boss Tony Fernandes has just tweeted his thanks to the authorities in Indonesia.

You can read more about Mr Fernandes - Asia's answer to Richard Branson - here.

AirAsia plane missing: profile of airline boss Tony Fernandes

07.38 Our correspondent Jonathan Pearlman, in Pangkalan Bun - where the bodies are being brought from the crash site - brings us the following update:

The two bodies from the crashed AirAsia flight that were returned to land earlier today have now been identified, prepared in coffins and flown to Surabaya. The Indonesian search authority said the bodies belonged to a boy, 140cm tall, wearing a blue shirt and brown trousers, and a woman, 160cm tall, wearing blue jeans and a dark blue shirt.

Some of the remaining five bodies found so far are due to land here soon and will be identified and flown off in similar fashion.

Separately, AirAsia owner Tony Fernandes is at the airport in Pangkalan Bun to meet with the Indonesian search authority.

07.13

06.59 More on that body recovered from the crashed plane.

Tatang Zaenudin, an official with the search and rescue agency, said:

This morning, we recovered a total of four bodies and one of them was wearing a life jacket.

06.48 Reuters - INDONESIA SEARCH AND RESCUE AGENCY SAYS BODY RECOVERED FROM AIRASIA JET WAS WEARING LIFE JACKET

Relatives of the missing passengers on board the AirAsia plane pray at Juanda Airport, in Surabaya, Indonesia (EPA)

06.25 Jonathan Pearlman in Palangkan Bun has spoken to the head of the search and rescue agency:

The Indonesian search authority says it expects bodies of survivors from the AirAsia flight to start washing up ashore along the coastline in the coming days. Air Vice Marshal Sunarbowo Sandi, the mission coordinator in Palangkan Bun, says strong winds and currents have already moved debris up to 30 miles since they were first seen yesterday. He says one more body was found today but poor weather and visibility has made searching all but impossible and is preventing authorities from flying all seven bodies back to shore. The bodies are on naval vessels; two have been flown to land by helicopter.

He says there has been no sign of the black box but a vessel with detection equipment is being dispatched. He is not aware of any bodies being found in life jackets. More than 90 divers are ready on ships to start searching but have been unable due to the poor weather conditions. He also said there had been no confirmation that the body of the plane has been spotted, though some search personnel have reported seeing something that "seemed" to be the plane.

06.20 This from Tom Phillips, our correspondent in Surabaya:

There are 75 ambulances lined up at Surabaya airport this morning in anticipation of the arrival of the victims' bodies.

It's not clear when the victims will start arriving here, but when they do they will be taken to the city's Bhayankara Hospital, around 6 miles away. Already six bodies have been recovered we now understand, including one wearing an AirAsia uniform.

Relatives have been holding prayer sessions this morning at the airport as they wait for news about the progress of the rescue operation.

> So many ambulances lined up outside military airport in Surabaya this morning to receive bodies of #QZ8501 victims pic.twitter.com/16xocpihlY

> — Tom Phillips (@tomphillipsin) December 31, 2014

> I counted nearly 30 ambulances on standby to take #QZ8501 victims' bodies to hospital in Surabaya for identification pic.twitter.com/PhMGY3uuzf

> — Tom Phillips (@tomphillipsin) December 31, 2014

06.10 Update: total of 7 bodies - 4 men, 3 women - recovered so far, says search chief. One was air hostess Khairunisa Haidar Fauzi,, who was in uniform, one was in a life jacket according to reports, and three were found still holding hands.

Indonesian police collect AirAsia passenger records from relatives to help identification of the victims at Juanda Airport, in Surabaya, Indonesia (EPA)

05.20 Seventh body has reportedly just been found. Our correspondent Jonathan Pearlman has just arrived in Pangkalan Bun airport, where Indonesian military just arrived with two bodies.

> #QZ8501: Search teams have just brought a body back to Pangkalan Bun from sea via helicopter http://t.co/fU1QeMQPFC pic.twitter.com/xrDVp5Qaqn

> — Channel NewsAsia (@ChannelNewsAsia) December 31, 2014

04.25 Three people killed on AirAsia flight QZ8501 were holding hands when their bodies were spotted floating in the Java sea off Indonesia, a pilot involved in the search for the missing plane has claimed.

Lieutenant Airman Tri Wobowo, who co-piloted the C130 Hercules aircraft that first saw debris of the plane on Tuesday, told Indonesian newspaper Kompas: "There are seven to eight people. Three [of them] again hold hands."

Members of an Indonesian search and rescue team carry a body on a stretcher during the recovery operation (AFP/Getty)

04.00 Searchers says they've seen a sonar image appears to show an aircraft lying upside down on the ocean floor. The newspaper quoted the agency as saying the image appeared to show an airplane upside down in 24-30 meters of water.

03.12 We have a little more on the bodies pulled up today: apparently three are male and three female including, according to reports, 20-year-old trainee flight assistant Khairunisa Haidar Fauzi. Ms Khairunisa’s father, Haidar Fauzi, has said: “This is what we expected, and the sooner the body is returned, the sooner we can have her back.”

> #PrayForAirAsia ✈ Air Asia flight attendant Khairunisa Haidar Fauzi was travelling on the missing flight. pic.twitter.com/RBBPdyUNaS

> — J (@jealousay) December 30, 2014

02.50 As we reported earlier, searchers found three more bodies this morning, including a flight attendant still wearing her AirAsia uniform, bringing the total to six so far, Fully clothed bodies could also indicate the plane was intact when it hit the water and support a theory that the Airbus A320-200 suffered an aerodynamic stall and plunged into the sea.

"The fact that the debris appears fairly contained suggests the aircraft broke up when it hit the water, rather than in the air," said Neil Hansford, a former pilot and chairman of consultancy firm Strategic Aviation Solutions.

> #QZ8501 search: Backpack, food, kid's shoes found by Indonesia ship Bung Tomo: @detikcom http://t.co/fU1QeMQPFC pic.twitter.com/QiXysgpqA4

> — Channel NewsAsia (@ChannelNewsAsia) December 31, 2014

02.10 AIrAsia boss is on his way to the island receiving bodies to comfort relatives.

> I hope to fly to evacuation site to thank everyone for putting in so much effort in finding the site. And keep everyone informed.

> — Tony Fernandes (@tonyfernandes) December 31, 2014

02.10 Stormy weather has forced Indonesian rescuers to suspend their search for the bodies.

"We are experiencing bad weather now. Rains and winds prevented us from resuming the search operation this morning," air force rescue coordinator S.B. Supriyadi told AFP.

Indonesian Navy divers inspect their gear upon arrival for the search operation for the victims of AirAsia flight QZ 8501 at the airport in Pangkalan Bun, Indonesia (AP)

National Search and Rescue Agency chief Bambang Soelistyo told a press conference Wednesday that six bodies had now been recovered, including a woman in crew uniform.

"As soon as the weather is clear, the bodies will be brought to Pangkalan Bun," the town with the nearest airstrip to the crash site, said Soelistyo.

Supriyadi said that hundreds of people from the military, police and national rescue agency were on standby waiting for clear weather in Pangkalan Bun.

> #QZ8501 search: DNA tests on recovered bodies being conducted by police, says police chief http://t.co/fU1QeMQPFC pic.twitter.com/3dieemkTkT

> — Channel NewsAsia (@ChannelNewsAsia) December 31, 2014

02.00 The UK air investigation bureau join will join today's search with special technology to track the exact location of the airplane beacon under water.

00.35 The Telegraph team in China has been speaking to families of the passengers of Malaysia Airlines Flight MH370 that disappeared in March and, unlike QZ8501, has still yet to be found.

“Many people say they share the pain and sorrow of the victims’ families, but only we, the families, know exactly how it feels. We have been there before,” said Steve Wang, whose mother was one of 239 people on the plane.

“I feel so sad that history is repeating itself. I don’t know why it is happening again,” he said.

Dai Shuqin, a 61-year-old who had five relations on MH370, said she had been constantly thinking about those caught up in the latest Asian air disaster. I pray for them to have at least one people survive,” she said. “If just one person might survive on QZ8501, it would give me hope for MH370.”

Mrs Dai said she was asking for a “miracle”. “I cannot believe that 10 months later another group of people has been on a lost plane again. All those lives!”

Jiang Hui, whose mother was on MH370, said: “I don't know how to describe the feeling I had when I heard [about QZ8501]”

“It was like waking up from a nightmare – I was covered in goose-bumps. How could there be so many disasters this year?”

Sudarsan Pattnaik works on a sand sculpture portraying the missing AirAsia and Malayasia Airlines planes, on Golden Sea Beach in Puri, in India's eastern Odisha state

00.30 Aviation experts believe the fuselage may be easily found as the aircraft probably only broke up when it hit the water.

"The fact that the debris appears fairly contained suggests the aircraft broke up when it hit the water, rather than in the air," Neil Hansford, a former pilot and chairman of consultancy firm Strategic Aviation Solutions, said on Wednesday.

00.20 Relatives had been holding out hope that against all odds, their family members would be saved. One father learned the horrible news that his daughter Maria Widodo had likely not made it.

Maria had recently graduated from the National Institute of Education, the Straits Times reported. In college she was part of her university’s guitar ensemble, along with her boyfriend, Andy Paul Chen, who is from Singapore.

Following news of the plane’s disappearance, Florentina Maria Widodo’s father changed his profile picture on Facebook to one of him and his daughter, and Chen posted the news that his girlfriend was on the flight.

> Our deepest condolences #airasiamissing pic.twitter.com/Nli9H4c2md

> — Bigi (@DrBigi) December 30, 2014

00.04 The grim task of identification of bodies from #QZ8501 will begin today. Family members have already been asked for photos and provided DNA. Due to bad weather, only three bodies have so far been recovered.

23.46 This is the search area teams will be concentrating on this morning - it's about the size of Wales.

> Malaysia’s @ChiefofNavy: today’s ongoing #QZ8501 search is split into four sea sectors totalling 5378 square km. pic.twitter.com/ha8AezcsjR

> — John Walton (@thatjohn) December 30, 2014

23.45 It is now approaching 7am in Jakarta.The search for more bodies - and clues as to the cause behind AirAsia Flight QZ8501's crash into the Java Sea - continues. It was a long night for families, who learnt the fate of their loved ones in the most devastating of ways.

Relatives of passengers on AirAsia flight QZ 8501 console each other (Getty)

## Indonesia

- ### News »

- ### World News »

- ### Asia »

- ### Singapore »

- ### Harriet Alexander »

Related Partners

- The best way to transfer money overseas

In Indonesia

### The search for AirAsia QZ8501

### Tsunami 10th anniversary

### Unclaimed possessions

### Boxing Day tsunami: then and now

### Creatures from beneath the sea

Top news galleries

### The search for AirAsia QZ8501

In pics: Wreckage and bodies from the missing AirAsia flight have been found.

### The 49 best British films of all time

Film

From Skyfall to Zulu, critic Barry Norman's choice of the 49 best British films of all time

Comments

### Hyper-realistic celebrity dolls

A portrait artist transforms off-the-shelf dolls into hyper-realistic models of celebrities

### The week in pictures

A round-up of our favourite photographs of the week

### Animal photos of the week

All creatures great and small in our ever popular animal gallery.

### New Year's Day swimmers

Swimmers plunge into the sea around the world on New Year's Day

### Pictures of the day

A thoughtful seal, a diving Super Woman and Kim Jong-un visits orphanage

### Celebrities and their winter coats

When fashion and practicality collide in an eruption of layers and nobody judges you for wearing the same outfit 98 times in a row

### On the road with Froome

Cyclist Chris Froome shares his Instagram moments with the Telegraph Magazine

### Culture stars who died in 2014

Culture News

We celebrate and remember the stars who passed away last year

Comments
Advertisement
How we moderate
telegraphuk
blog comments powered by Disqus
Advertisement

Latest Video»

### AirAsia search: two large objects found

### Animation: train fare rises explained

### Obama: North Korea's hacking has caused 'a lot of damage'

### Cute puppies struggle to walk in new shoes

### One to watch! 12-year-old Gerrard shows off his skills

### Russia's Red Army Choir get 'Happy'

More from the web

Advertisement

More from the web

News Most Viewed

- TODAY
- PAST WEEK
- PAST MONTH

1. Couple stranded in New York with newborn baby freed from £130,000 medical bill
2. Holiday windfall for Britons as euro slides
3. Meet the Arab Christians who want to fight for Israel
4. Gales and snow to divide the country
5. Has Stanford University found a cure for Alzheimer's disease?

1. AirAsia: search resumes for remaining bodies
2. Top Gear: What really happened in Patagonia?
3. 'Young people lost generation who can't fix gadgets'
4. How to see Santa (aka the ISS) flying by on Christmas Eve
5. The baby from Teletubbies reveals herself

1. AirAsia: search resumes for remaining bodies
2. Gunman and two hostages killed in bloody end to Sydney siege
3. Top Gear: What really happened in Patagonia?
4. 'Young people lost generation who can't fix gadgets'
5. World's fattest man Keith Martin dies, aged 44

Advertisement

More from the web

MORE FROM TELEGRAPH.CO.UK

US News

### Latest and breaking stories from the United States

View
Football

### Catch up on all the latest football news

View
Audi

### Audi R18 in pictures

View
Goodwood

### The very best of Goodwood's Moving Motor Show in pictures

View

Back to top

- HOME
- News
- UK News
- Politics

- Long Reads

- Wikileaks
- Jobs

- World News
- Europe
- USA
- China

- Royal Family News

- Celebrity news
- Dating

- Finance
- Education
- Defence
- Health

- Weird News

- Editor's Choice
- Financial Services

- Pictures
- Video
- Matt
- Alex

- Comment

- Blogs
- Crossword

- Contact Us
- Privacy and Cookies
- Advertising
- Fantasy Football

- Tickets

- Announcements
- Reader Prints

- Follow Us
- Apps
- Epaper
- Expat

- Promotions
- Subscriber
- Syndication

© Copyright of Telegraph Media Group Limited 2015

Terms and Conditions

Today's News

Archive

Style Book

Weather Forecast